#
# spec file for package spyder
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           spyder
Version:        2.3.5.2
Release:        3.2
Url:            http://spyderlib.googlecode.com
Summary:        Scientific PYthon Development EnviRonment
License:        MIT
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/s/spyder/spyder-%{version}.zip
Source1:        spyder-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  IPython
BuildRequires:  fdupes
BuildRequires:  python-Sphinx >= 0.6.0
BuildRequires:  python-devel >= 2.5
BuildRequires:  python-matplotlib
BuildRequires:  python-numpy
BuildRequires:  python-pep8
BuildRequires:  python-psutil
BuildRequires:  python-pyflakes >= 0.5.0
BuildRequires:  python-qt4 >= 4.6
BuildRequires:  python-rope => 0.9.2
BuildRequires:  python-scipy
BuildRequires:  unzip
BuildRequires:  update-desktop-files
Requires:       python-spyderlib = %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A Scientific Python development environment, an alternative to IDLE 
with powerful interactive features such as variable explorer (with
GUI-based editors for dictionaries, lists, NumPy arrays, etc.), object
inspector, online help, and a lot more.

%package -n python-spyderlib
Summary:        Python GUI components
Group:          Development/Languages/Python
Requires:       python-Sphinx >= 0.6.0
Requires:       python-qt4 >= 4.6
Recommends:     IPython
Recommends:     python-matplotlib
Recommends:     python-numpy
Recommends:     python-pep8
Recommends:     python-psutil
Recommends:     python-pyflakes >= 0.5.0
Recommends:     python-pylint
Recommends:     python-rope >= 0.9.2
Recommends:     python-scipy

%description -n python-spyderlib
The spyderlib module provides powerful console and
editor related widgets to your PyQt4 application.

%package doc
Summary:        Documentation for %{name} and python-spyderlib
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description doc
Documentation and help files for both %{name} and python-spyderlib

%lang_package
%prep
%setup -q
# Fix wrong-file-end-of-line-encoding RPMLint warning
sed -i 's/\r$//' doc/*.rst
sed -i 's/\r$//' spyderlib/userconfig.py
sed -i 's/\r$//' LICENSE

%build
python setup.py build && rm build/lib/spyderlib/doc/.buildinfo

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# remove windows stuff
rm %{buildroot}%{_bindir}/spyder_win_post_install.py
# create missing directories
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
# install the icon
pushd %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
ln -s %{python_sitelib}/spyderlib/images/spyder.svg %{name}.svg
popd
%find_lang spyderlib %{name}.lang
%find_lang p_breakpoints %{name}.lang
%find_lang p_profiler %{name}.lang
%find_lang p_pylint %{name}.lang
%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{python_sitelib}
# Documentation belongs into _docdir:
rm -r %{buildroot}%{python_sitelib}/spyderlib/doc
rm -f build/lib/spyderlib/doc/.buildinfo

%files
%defattr(-,root,root,-)
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/pixmaps/%{name}.png

%files -n python-spyderlib
%defattr(-,root,root,-)
%doc LICENSE README.md
%{python_sitelib}/spyderlib/
%{python_sitelib}/spyderplugins/
%{python_sitelib}/spyder-%{version}-py*.egg-info
%exclude %{python_sitelib}/spyderlib/locale/
%exclude %{python_sitelib}/spyderplugins/locale/

%files doc
%defattr(-,root,root,-)
%doc build/lib/spyderlib/doc/

%files lang -f %{name}.lang
%defattr(-,root,root)
%{python_sitelib}/spyderlib/locale
%{python_sitelib}/spyderplugins/locale/

%changelog
* Mon Jun 29 2015 toddrme2178@gmail.com
- Update to 2.3.5.2
  * Note: Versions 2.3.5 and 2.3.5.1 have serious startup bugs on
    Windows and Mac respectively. Hence they are not listed here.
  * New features
  - Editor
    + Add support for Jedi 0.9
  - IPython Console
    + Add initial support for IPython/Jupyter 4.0
  - Main Window
    + Improve how Spyder looks in MacOS X
    + Several fixes to prevent startup crashes
  * Bug fixes
  - Issue 2468 - 'Connect to existing kernel' fails if json file not in PWD
  - Issue 2466 - No Notification of Running Instance
  - Issue 2463 - Failure to preserve Matplotlib backend when using symbolic math
  - Issue 2456 - Launching IPython console fails because of errors importing Pandas or Matplotlib
  - Issue 2452 - os.system causes TypeError in Python 3
  - Issue 2448 - Spyder crashes using Variable Explorer with BeautifulSoup
  - Issue 2446 - When importing putting two periods in a row produces an error in a Python console
  - Issue 2363 - Spyder fails to start because of problems with lockfile
  - Issue 2356 - Block comment incorporating whitespace excludes last line
  - Issue 2341 - IPython console: "sre_constants.error: unbalanced parenthesis" while typing
  - Issue 2314 - Cell highlighting not updated after closing the FindReplace widget
  - Issue 2302 - Closing all files in editor shouldn't leave it empty
  - Issue 2299 - IPython preference "Automatically load Pylab and Numpy Modules" not followed
  - Issue 2298 - Cannot stop executing when runing a flask app with debug=True
  - Issue 2285 - Copying from Spyder and pasting into LibreOffice displays strange comments
  - Issue 2228 - Shortcut to run cells on Mac is not working
  - Issue 2188 - can't run win_post_install from pip
  - Issue 2171 - Spyder Mac apps (for Python 2 and 3) hang on startup with OSX 10.9.5
  - Issue 2028 - Background color of theme is not set properly on Mac OSX
  - Issue 1957 - Python 3 Mac app can't start Python or IPython consoles
  - Issue 1844 - "Set as current console's working directory" button not working on Python 3
  - Issue 1615 - Mac app - Matplotlib does not work with Canopy
  * Pull requests
  - PR 2486 - Stop using IPython.lib.kernel 0.13.2 shim and add initial support for Jupyter
  - PR 2484 - Remove unnecessary changes to detected kernel json file when connecting to external kernels
  - PR 2434 - Match for pylint when parsing pylint version
  - PR 2411 - Improve github issue template
  - PR 2377 - Fix the fact that spyder_win_post_install.py can't be run from pip
  - PR 2293 - Hide menu icons on Mac OS X
  - PR 2247 - Add support to run Python programs on xfce and xterm external terminals
  - PR 2216 - Fix broken png files: libpng 1.6.2 and newer has stricter iCCP rules
* Tue Mar 24 2015 toddrme2178@gmail.com
- Build docs for python 3.x
- Update to 2.3.4:
  * New features
  - Debugging
    + After pressing the Debug button (or Ctrl+F5) move to the first
    breakpoint
  - IPython Console
    + Drop support for Sympy versions less than 0.7.3
  - Python Console
    + Remove support to run system commands with ! (like !diff)
  - Editor
    + Accept drops from compressed files on Windows
  * Bug fixes
  - spyder crashes if ipython installed but not pygments
  - Cannot plot inline in IPython console on Linux
  - Update French translations for 2.3.4
  - Importing a module with debugger causes "TypeError: decoding Unicode is
    not supported"
  - SyntaxErrors with Python 3.2
  - Object Inspector is not showing "No documentation available" for objects
    without docstring
  - IPython does not work with brewed or virtualenv Python(s) in MacOSX
  - Spyder2.3.3 Code completion breaks
  - Spyder's WM_CLASS is empty, resulting in unexpected behavior for task
    managers
  - Code completion issue with Jedi
  - IPython consoles are not named correctly when connecting to existing
    kernels and passing the full kernel path
  - runfile with path containing apostrophes (quotes) will not work
  - Long NumPy arrays throw off errors
  - Special character "!" is not processed correctly when debugging in Python
    consoles
  - Spyder crashes on Windows because of non-ascii chars in working directory
  - Don't execute external commands (!) when running pdb in python consoles
  - Execute until first breakpoint when pressing the Debug button
  - Dragging (not dropping) file from 7zip over spyder window causes
    TypeError in dragEnterEvent
  - spyderlib.utils.external overrides modules for script execution
  - spyder 2.3 ipython console startup code or file not working
  - Running in external system terminals is not working on Windows and Python
    3
  - Spyder crashes on launch trying to load the project config file
    (.spyderproject)
  - raw_input borks with '!'
  - Plot A List Of Floats In Variable Explorer Not Possible
  - Problems with sitecustomize because of pickleshare library
  - "Highlight occurrences" setting is lost after IDE restart
  - Mac app - Sometimes it's not possible to get the user env vars
  - The PYTHONPATH manager on the Mac app does not work with the EPD64
    interpreter
  - Ctrl-C doesn't copy to clipboard in object inspector
  * Pull requests
  - Update French translations
  - Improve message for no docstring
  - catch a reason to crash on startup
  - Fix a bug in completion if callback value is not converted to string
  - Open configuration file with utf-8 encoding on Windows and Python 2
  - Fix zlib segmentation fault in Anaconda 3.4 Linux
- Update to 2.3.3:
  * New features
  - Editor
    + Use the Jedi library to do code completions
    + Add Ctrl+= as a shortcut to do Zoom in and Ctrl+0 to reset zoom
    + Add an option to show blank spaces, under the Source menu. There is
    also an option to make this permanent under Preferences > Editor.
  - IPython Console
    + Don't print DataFrames as html tables because this won't be supported
    since IPython 3.0
    + Drop support for IPython 0.13
    + Support the upcoming 3.0 version
    + Add Ctrl+T as shortcut to open new consoles
    + Simplify how consoles are named
  - Variable Explorer
    + More optimizations to handle big DataFrames and NumPy arrays (i.e. with
    more than 1e6 elements).
  - Main Window
    + Add Ctrl+W and Ctrl+F4 to close tabs in all platforms
    + Show shortcuts to move to each pane in View > Panes
  * Bug fixes
  - Visual help for indentation: draw spaces and tabs
  - Allow the file explorer to open any file into the editor as text
  - Augment or replace rope with Jedi
  - Kill button 'clicked' signal is connected but never disconnected on the
    python shell
  - Add support to get code completions for compiled modules (e.g. OpenCV)
  - Debug ignores breakpoints, if there's no ASCII characters in a file path
  - Creating file gives TypeError on Python 3
  - Keyboard shortcut to come back to normal zoom level
  - Shortcuts to create and close IPython consoles
  - Transition to git and github
  - Evaluating cell or selection in Python consoles takes ages
  - Spyder with GTK/GTKAgg backend on GNOME freezes
  - Matplotlib backend in Mac can't be changed when using PySide
  - exception in spyder internal console when typing 'exit(' in editor
  - autocomplete in the middle of a word
  - Your IPython frontend and kernel versions are incompatible
  - Winpdb (F7) doesn't work in Python 3
  - TkAgg backend unresponsive window on Linux and OS X
  - Improve inline backend options
  - Pandas Dataframe not opening in Variable Explorer
  - "About spyder" and "Report issue ..." output errors
  - Profiler - sorting by Total Time sorts by string order, not numeric order
  - Unable to bring up tutorial
  - Bug on Variable Explorer while viewing DataFrames, with timestamp columns
  - Missing py27 dmg download
  - PYTHON pathmanager on windows 8 does not work properly
  - Spyder 2.3.2 freezes when viewing big collections on the Variable
    Explorer
  - UnicodeDecodeError in the Internal console when trying to run a file with
    non-ascii chars and synatx errors in it
  - Go to definition menu item inactive with rope present.
  - iPython console rendering of pandas.DataFrame.repr_html() note in
    changelog
  - Small typo in Help : Plotting examples
  - Closing takes a long time with Python 3.4
  - UnicodeDecodeError when inspecting pandas DataFrame in ipython console
  - Update French translations for 2.3.3
* Sat Dec  6 2014 toddrme2178@gmail.com
- Update to 2.3.2:
  * Editor
  - Improve cells visualization
  - Add support for drag selection and improve look of
    line number area
  - Open on it any text file present in the Variable Explorer
  - View and edit IPython notebooks as Json files
  - Syntax highlighting for Json and Yaml files
  * Variable Explorer:
  - Import csv files as Pandas DataFrames
  - Improve browsing speed for NumPy arrays and DataFrames with more
    han 1e5 elements
  * IPython Console
  - Add a stop button to easily stop computations
* Mon Oct 13 2014 toddrme2178@gmail.com
- Fix icon directory ownership
* Thu Sep 18 2014 toddrme2178@gmail.com
- Update to 2.3.1
  * New features since
  * Variable Explorer
  * Support for Pandas DataFrame's and TimeSerie's types
  * Support for Numpy 3D arrays
  * Drag and drop works for all its supported file types
    (e.g. images, mat files, json files, etc)
  * Editor
  * F9 runs the current line under the cursor if nothing is
    selected
  * Focus remains on it after evaluating cells and selections
    (an option was added to return to the old behavior)
  * IPython console
  * Connect to external kernels through ssh
  * Object Inspector
  * Add a tutorial for beginners
  * Main Window
  * Improve style on Mac
  * Bug fixes
  * Issue  93  Variable explorer: allow array editor to deal
    with arrays with more than 2 dimensions
  * Issue  1160  Variable Explorer: add support for pandas
    objects
  * Issue  1305  mayavi plot hangs when IPython graphics backend
    is inline (default)
  * Issue  1319  Spyder is not getting its taskbar icon right in
    Win 7/8
  * Issue  1445  Linux style middle mouse button paste not
    executed in console
  * Issue  1530  Wrong encoding for date in pylint widget
  * Issue  1590  Add numpy matrices as a supported type to the
    Variable Explorer
  * Issue  1604  spyder 2.2.5 freezes with netCDF4-python
  * Issue  1627  Run selection (F9) changes focus to Python
    interpreter, but ex-Matlab users expect the
    focus to remain on the editor
  * Issue  1670  Provide a "Run current line" feature
  * Issue  1690  Feature request: connect to existing IPython
    kernel over ssh
  * Issue  1699  Option to disable middle button paste
  * Issue  1783  The new cell delimiter when converting a
    notebook to python file is # In[`*`]
  * Issue  1863  Ctrl-C doesn't work in a *restarted* IPython
    console
  * Issue  1893  Matplotlib plots do not display correctly in
    2.3.0 (when running in dedicated python
    interpreter)
- Update dependencies
* Mon Jul 14 2014 toddrme2178@gmail.com
- Add spyder-rpmlintrc as source file
- Remove not-applied patch version_check.patch
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 2.3.0
  - New features
  * Python 3 support
  * Editor
  * Use the Tab key to do code completions
  * Highlight cells, i.e. portions of a file delimited by separators of the form `# %%%%`
  * First-class support for Enaml files
  * Syntax highlighting for Julia files
  * Use Shift+Tab to show the signature corresponding to a function/method while it's been called
  * Do code completions using the tokens (or words) found in a file
  * Token-based completions work for any file type supported by the Editor
  * Add a new tooltip widget (borrowed from the IPython project) to better handle how to show function signatures
  * IPython console
  * Assign the keyboard shortcut Ctrl+Shift+I to move to it
  * Open a console by default at startup
  * Give visual feedback when opening a console
  * Show kernel error messages in the client tab
  * Object Inspector
  * Add an intro message to explain how to use it
  * New style based on the Bootswatch Cerulean theme
  * Main Window
  * Reorganize several menus
  * Under the hood
  * Improve startup time
  * Develop a new way to update configuration defaults (that doesn't involve resetting user settings)
  - Bug fixes
* Fri Feb 14 2014 dmueller@suse.com
- remove python-pylint buildrequires, doesn't seem  to be used
* Wed Nov 13 2013 p.drouand@gmail.com
- Define %%{python_sitelib} to fix build with SLE
* Tue Oct 15 2013 toddrme2178@gmail.com
- Update to version 2.2.5
  * Issue  1322  Problems with scientific_startup in other interpreters from the one Spyder is running on
  * Issue  1337  Mac app - Update to Qt 4.8.4 for HDPI
  * Issue  1450  IPython kernel cpu usage increases with time
  * Issue  1520  LinuxColor for ipython plugin
  * Issue  1551  /doc/installation.rst: update Arch Linux package link
  * Issue  1560  spyder 2.2.3 incompatible with pylint 0.25.1 on Windows
  * Issue  1564  Fix several Editor cell problems
  * Issue  1578  Typo in your 'About Spyder...' dialog.
  * Issue  1581  Cannot launch Spyder 2.2.4 installed from DMG on Mac OS X.
  * Issue  1589  Mention what types of objects our Variable Explorer support in our docs
  * Issue  1595  Fail to start an ipython console when variable explorer autorefresh is turned off in Preferences
  * Issue  1596  Spelling mistake in dialog ('loose' --> 'lose')
  * Update our Mac application to the latest versions of Python, Qt and PyQt (now it's based in Homebrew).
  * Several important compatibility fixes for PySide.
  * Improve our support for IPython 1.0+.
* Sat Oct 12 2013 p.drouand@gmail.com
- Update to version 2.2.4 (bnc#849811)
  * Fix issue 347: Matplotlib hangs on Mac if using PySide
  * Fix issue 1265: Create a Debug menu to easily show how to set breakpoints
  * Fix issue 1489: Project Explorer does not load all projects in workspace.
  * Fix issue 1516: Make Spyder compatible with both IPython 0.13 and 1.0
  * Fix issue 1531: Pyflakes version check is looking for 0.5.0 only
  * Fix issue 1539: /tmp/spyder is owned by the first user on the server
    to launch spyder
  * Make Spyder compatible with SymPy 0.7.3+
  * Add shortcuts to the tooltips of all toolbars
  * Make IPython Console work better if Matplotlib is not installed
- Changes between version 2.2.3 and 2.2.2
  * Fix issue 634: Debugging: Lingering break points
  * Fix issue 639: Project Explorer: horizontal size issue (added an
    optional horizontal scrollbar. This option may be enabled/disabled
    in the widget context menu)
  * Fix issue 749: Outline Explorer: Duplicate entries
  * Fix issue 852: Implement matlab-like cell features
  * Fix issue 1388: Add an "About Spyder dependencies" dialog box
  * Fix issue 1438: "runfile" doesn't work correctly if unicode_literals has
    been imported (replaced backslashes by slashes in paths)
  * Fix issue 1515: Add an option to use the same interpreter Spyder is
    running on as "Python executable" for external consoles
  * Fix issue 1522: licenses of the images (especially the .png)
  * Fix issue 1526: Build script (setup.py) includes the wrong version of
    pyflakes/rope in Windows installer
  * Fix issue 1527: please include the LICENSE file in the source package
  * New "Run selection" (F9), "Run cell" (Ctrl+Enter) and "Run cell and
    advance" (Shift+Enter) actions in "Run" menu entry, as a replacement
    to the old "Run selection or block" and "Run block and advance" actions.
  * Added "Optional Dependencies" dialog box in "?" menu.
  * Editor: added Monokai and Zenburn syntax coloring schemes.
  * Keyboard shortcuts: removing deprecated shortcuts at startup. Otherwise,
    when renaming the name of a registered shortcut (in the code), the old
    shortcut will stay in Spyder configuration file and opening the Preferences
    dialog will show a shortcut conflict dialog box.
  * External console tabs: fixed history browsing with Ctrl+Tab and added
  Shift+Ctrl+Tab support.
  * Preferences>Console>Advanced: new option to switch between the default Python
  executable
  * Run Icons: removed deprecated images, updated other images to the new design
    setup.py/Windows installers: now building CHM documentation for Windows
  * SPYDER_DEBUG environment variable now supports 3 levels of debug mode:
    SPYDER_DEBUG=0 or False: debug mode is off
    SPYDER_DEBUG=1 or True: debug level 1 is on (internal console is disconnected)
    SPYDER_DEBUG=2: debug level 2 is on (+ logging coms with external Python processes)
    SPYDER_DEBUG=3: debug level 3 is on (+ enabling -v option in external
    Python processes and debugging editor)
- Changes between version 2.2.2 and 2.2.1
  * Fix issue 1497: Spyder 2.2.1 does not work with Python < 2.7
  * Fix issue 1498: TypeError thrown by IPython Console when the pager is off
  * Fix issue 1499: Console (Terminal) throws NotImplementedError for Home/End keys
  * Fix issue 1509: Add support for javascript syntax highlighting
  * Fix issue 1510: Problems with zooming in/out
  * Add new icons to the Run, Debug and Main toolbars
  * Update Pylint plugin to work with pylint 1.0
  * Add Ctrl/Cmd+[+,-] to zoom in/out in the Editor
  * Disable Crtl+MouseWheel to zoom in/out in Mac (See  Issue 1509 )
  * Update Pandas and Matplotlib in our Mac application
* Tue Aug 13 2013 speilicke@suse.com
- Updato to version 2.2.1 (bnc#833564):
  + Upstream provides no changelog
- Install documentation into correct location
* Mon Apr 22 2013 hrvoje.senjan@gmail.com
- Added version_check.patch, fixes detection of pyqt version
* Thu Feb 14 2013 fisiu@opensuse.org
- Update to version 2.1.13:
  * Bug fixes
* Thu Nov 29 2012 toddrme2178@gmail.com
- Fix typo
* Thu Nov 29 2012 toddrme2178@gmail.com
- Update to Version 2.1.11
  * Bug fixes
- Split documentation package
- Split spyderlib package and binary package, since spyderlib is
  used independently of the spyder gui
- Spec file cleanups
* Tue Jun 12 2012 toddrme2178@gmail.com
- Install desktop file, with appropriate icon
- Tag documentation in spec file
- Fix rpmlint warnings
* Mon May 28 2012 toddrme2178@gmail.com
- Update to Version 2.1.10
  * Bug fixes
* Tue May 22 2012 toddrme2178@gmail.com
- Update dependencies
- Clean up spec file formatting
- Update to Version 2.1.9
  * Bug fixes
- Update to Version 2.1.8
  * Bug fixes
- Update to Version 2.1.7
  * Bug fixes
  * Variable explorer/Array editor: added support for masked arrays
  * Showing Spyder's internal console automatically when there is a traceback
  * Do not crash when a 3rd party plugin failed to import
  * Editor:
  * Automatic insertion of single, double and triple quotes
  * Automatically colons insertion when pressing Enter after 'if', 'def', etc
  * Don't trigger code completion on comments if text ends with a dot
  * Added keyboard shortcut (Ctrl+Shift+Escape) to clear the console
  * Added keyboard shortcut (Ctrl+P) to print current file (thanks to fheday at gmail dot com for the contribution)
  * Code introspection features (code completion, calltips, go-to-definition) are now working even if script has syntax errors
- Update to Version 2.1.6
  * Bug fixes
- Update to Version 2.1.5
  * Bug fixes
  * Debugging: when a non-empty SPYDER_DEBUG environment variable exists, Spyder switch to debug mode (log files are created in user's home directory and debug prints are available in the terminal)
  * Variable explorer/Dictionary editor: added option to plot histogram from a 1-D array
  * Console:
  * standard Python interpreter is now a real Python interactive session: the older implementation was running a startup script and tried to emulate a standard Python interactive session (changing attributes like __name__, running the PYTHONSTARTUP script, etc.). But this implementation was not close enough to the standard Python interactive session, i.e. when you execute `python` outside Spyder, without any argument. A recent bug report confirmed this: the PYTHONSTARTUP script was executed but not exactly the same way as it is outside Spyder: for example, doing `from __future__ import division` in the startup script had no effect whereas it did outside Spyder.
  * when running a standard Python interpreter, instead of running the startup script (spyderlib/widgets/externalshell/startup.py), the shell widget (ExternalPythonShell) simply runs the python executable with -u -i options, that's all. So now, the PYTHONSTARTUP script is executed as expected.
  * Scientific startup script (default PYTHONSTARTUP in Spyder): added floating point division (from __future__ import division)
  * PySide support:
  * Added new "Qt (PyQt/PySide)" settings group in "External modules" tab
  * It is now possible to select the Qt-Python bindings library: default (i.e. depends on the QT_API environment variable), PyQt or PySide
  * The PyQt input hook has been adapted for PySide, so it is now possible to do interactive (non-blocking) plotting with PySide
  * New options for standard Python interpreters (no effect on IPython):
  * "Merge process standard output/error channels": merging the output channels of the process means that the standard error won't be written in red anymore, but this has the effect of speeding up display
  * "Colorize standard error channel using ANSI escape codes": this method is the only way to have colorized standard error channel when the output channels have been merged
  * Internal console (Issue 868): output is now immediately available
  * "Maximize current plugin" action: now automatically shows the "Outline" plugin when maximizing the "Editor" plugin
  * Editor/Outline comment separators: allow space betwee hash and dash, e.g "# --- Outline Separator"
- Update to Version 2.1.4
  * Bug fixes
  * Console:
  * option "Open an IPython interperter at startup" is now *explicitely* disabled for IPython v0.11+ (these versions of IPython are not fully supported through Spyder's console plugin)
- Update to Version 2.1.3
  * Bug fixes
  * Variable explorer performance were improved, especially when dealing with very long sequences -- See this discussion: http://groups.google.com/group/spyderlib/browse_thread/thread/3a7ef892695e417a
  * Variable explorer / dictionary editor: added support for unknown objects -- this allows browsing any object attributes -- This is still experimental.
- Update to Version 2.1.2
  * Bug fixes
  * File/Project explorer:
  * Added "Delete" keyboard shortcut to remove selected file(s)/folder(s)
  * SCM integration: added support for !TortoiseHg v2 (only v1 was supported)
  * Console/Matplotlib options: the backend may now be set separately from the Matplotlib patch
  * Console:
  * The Matplotlib patch is only applied for Matplotlib <=v1.0
  * !PyQt API version issues (error like "!ValueError: API 'QString' has already been set to version 1"): the "ignore setapi errors" option is disabled by default, to avoid masking these errors and associated tracebacks
- Update to Version 2.1.1
  * Bug fixes
- Update to Version 2.1
  * Bug fixes
  * New *Profiler* plugin (thanks to Santiago Jaramillo)
  * New experimental *IPython* plugin embedding IPython's Qt console: see [http://spyder-ide.blogspot.com/2011/08/preview-of-new-ipython-plugin-for.html here]
  * General:
  * Main window:
  * added "Custom window layouts" management (see menu "View")/handling 3 custom layouts: default shortcuts Shift+Alt+FX to switch to/from layout #X and Ctrl+Shift+Alt+FX to set layout #X
  * "General" preferences page: added option to set the Qt windows style, depending on platform (Plastique, Cleanlooks, CDE, Windows...)
  * Menu "?": added menu entry to report Spyder issues, filling automatically informations on your configuration
  * Reorganized "Run"/"Source" menu, added "Interpreters" menu
  * Fixed application name for Gnome 3/Fedora 15
  * Command line options: added option "--defaults" to reset settings (stored in .spyder.ini) to defaults (a lot of settings are preserved: shortcuts, window layouts, ...) -- this is less brutal than "--reset" which reset all settings by removing all configuration files related to Spyder
  * *Outline* (function/class browser) is now a plugin in itself, embedded in its own dockwidget: Spyder's window layout is even more customizable than before
  * *Code completion*
  * (Editor/Console): entries starting with an underscore character are now placed to the end of the suggested list
  * (Editor/Console): Import statements are now completed correctly
  * *Console*:
  * Major code cleaning: running Python applications in Spyder has never been cleaner and is very close to a simple Python interpreter
  * Added built-in function `open_in_spyder` to open a file in Spyder's source code editor from the console
  * Standard Python interpreter:
  * now refresh the variable explorer at each new prompt (even if auto-refresh is disabled -- actually, this is the typical use case)
  * added support for basic special commands (%%pwd, %%ls, %%clear) and system commands (starting with '!', e.g. !dir or !ls)
  * added [http://spyder-ide.blogspot.com/2011/09/new-enhanced-scientific-python.html "scientific" startup script] with support for numpy, scipy and matplotlib
  * Preferences (External modules tab):
  * added an option to set !PyQt API to v1 or v2 -- this avoids issues with Enthought Tool Suite or any other library/program using !PyQt API v2 which is *not* the default API for Python 2
  * changed matplotlib patch to fix compatiblity issue with !PyQt API v2
  * Preferences (Advanced Settings tab): added option "Python executable" to customize path to Python interpreter executable binary
  * *Variable explorer*:
  * New HDF5 plugin ([http://code.google.com/u/DavidAnthonyPowell/ DavidAnthonyPowell]): import/export HDF5 files to/from the variable explorer
  * Dictionary editor/Variable explorer:
  * Added support for more NumPy data types
  * Added action "Resize rows to contents" (partially implements feature requested with Issue 807)
  * *Editor*:
  * find/replace:
  * added support for *multiline* regular expression search pattern
  * added support for *multiline* regular expression text replacement
  * added button "Highlight matches" to highlight all found results
  * syntax highlighting: added support for OpenCL, gettext files, patch/diff files, CSS and HTML files
  * support for "2 spaces" and "tabs" indentation characters
  * new code analysis feature: added support for the [http://pypi.python.org/pypi/pep8 pep8] style guide checker
  * "Comment" and "Uncomment" actions were replaced by a single "Comment/Uncommment" toggle action
  * (Fixes  Issue 811 ) "Run configuration": added "Run in an external system terminal" option
  * *File explorer* and *Project explorer*:
  * great performance improvement (using a multithreaded file system model)
  * Added minimalist SCM support (Mercurial and git are currently supported)
  * *File explorer*: added an option to "Show current directory only"
  * *Project explorer*: this plugin was entirely rewritten to improve performances and usability
  * *Pylint plugin*:
  * added option to save file before analyzing it
  * *Spyder's console embedded in your application (spyderlib.widgets.internalshell):
  * in traceback, a clickable link now opens the associated file in Spyder (if application was launched from Spyder with monitor enabled)
  * Application sample embedding Spyder's internal shell: upgraded to guidata v1.4+ (simplified build script a lot!)
- Update to Version 2.0.12
  * Bug fixes
  * (Fixes Issue 655) Editor/pyflakes-powered code analysis: warnings are now ignored for lines containing "pyflakes:ignore"
  * Internal console (Spyder debugging only): turned off the multithreaded mode
- Update to Version 2.0.11
  * Bug fixes
  * File explorer widget/plugin: improved performances (widget is now populated in a separate thread)
  * Spyder crash dialog: warning the user about the '--reset' option (this will remove all configuration files)
* Sun Apr 17 2011 saschpe@gmx.de
- Initial version (2.0.10)
